@@ -140,7 +140,7 @@ return [
 		],
 
 		/**
-		 * Room
+		 * Conversation (Room)
 		 */
 		[
 			'name' => 'Room#getRooms',
@@ -338,10 +338,10 @@ return [
 		],
 
 		/**
-		 * Files
+		 * FilesIntegration
 		 */
 		[
-			'name' => 'Files#getRoom',
+			'name' => 'FilesIntegration#getRoomByFileId',
 			'url' => '/api/{apiVersion}/file/{fileId}',
 			'verb' => 'GET',
 			'requirements' => [
@@ -349,15 +349,14 @@ return [
 				'fileId' => '.+'
 			],
 		],
-
-		/**
-		 * PublicShare
-		 */
 		[
-			'name' => 'PublicShare#getRoom',
+			'name' => 'FilesIntegration#getRoomByShareToken',
 			'url' => '/api/{apiVersion}/publicshare/{shareToken}',
 			'verb' => 'GET',
-			'requirements' => ['apiVersion' => 'v1'],
+			'requirements' => [
+				'apiVersion' => 'v1',
+				'shareToken' => '.+',
+			],
 		],
 
 		/**
@@ -384,34 +383,17 @@ return [
 				'apiVersion' => 'v1',
 			],
 		],
-		[
-			'name' => 'Command#update',
-			'url' => '/api/{apiVersion}/command/{id}',
-			'verb' => 'PUT',
-			'requirements' => [
-				'apiVersion' => 'v1',
-				'id' => '^\d+$',
-			],
-		],
-		[
-			'name' => 'Command#destroy',
-			'url' => '/api/{apiVersion}/command/{id}',
-			'verb' => 'DELETE',
-			'requirements' => [
-				'apiVersion' => 'v1',
-				'id' => '^\d+$',
-			],
-		],
 
 		/**
-		 * Webinary
+		 * Webinar
 		 */
 		[
-			'name' => 'Webinary#setLobby',
-			'url' => '/api/{apiVersion}/room/{token}/webinary/lobby',
+			'name' => 'Webinar#setLobby',
+			'url' => '/api/{apiVersion}/room/{token}/{webinar}/lobby',
 			'verb' => 'PUT',
 			'requirements' => [
 				'apiVersion' => 'v1',
+				'webinar' => 'webinary?',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
