@@ -71,6 +71,14 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} inviterede dig til en gruppesamtale: {call}",
     "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
     "A group call has started in {call}" : "Et gruppeopkald er startet i {call}",
+    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato. Brug formatet ÅÅÅ-MM-DD",
+    "Request password" : "Anmod om adgangskode",
+    "This conversation has ended" : "Samtalen er slut",
+    "None" : "Ingen",
+    "User" : "ruger",
+    "Everyone" : "Alle",
+    "Disabled" : "Deaktiveret",
+    "Users" : "Brugere",
     "TURN server URL" : "TURN server URL",
     "Validate SSL certificate" : "Godkend SSL certifikat",
     "STUN server URL" : "STUN server URL",
@@ -78,28 +86,91 @@ OC.L10N.register(
     "UDP and TCP" : "UDP og TCP",
     "UDP only" : "kun UDP",
     "TCP only" : "kun TCP",
-    "[Unknown user name]" : "[Ukendt brugernavn] ",
     "Copy link" : "Kopier link",
+    "No other people in this call" : "Ingen andre deltager i dette opkald",
+    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
+    "Share this link to invite others!" : "Del dette link for at invitere andre!",
+    "Share whole screen" : "Del hele skærmen",
+    "Share a single window" : "Del et vindue",
+    "Show your screen" : "Vis din skærm",
+    "Stop screensharing" : "Stop skærmdeling",
+    "No audio" : "Ingen lyd",
+    "Mute audio (m)" : "Slå lyden fra (m)",
+    "Unmute audio (m)" : "Slå lyden til (m)",
+    "Disable video (v)" : "Slå video fra (v)",
+    "Enable video (v)" : "Slå video til (v)",
+    "Screensharing options" : "Skærmdeling indstillinger",
+    "Enable screensharing" : "Slå skærmdeling til",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
+    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
+    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
+    "Your screen" : "Din skærm",
+    "Show screen" : "Vis skærm",
+    "Disable video" : "Deaktiver video",
+    "Enable video" : "Slå video til",
+    "Favorite" : "Foretrukken",
     "Leave conversation" : "Forlad samtale",
     "Delete conversation" : "Slet samtale",
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
+    "Contacts" : "Kontakter",
+    "Groups" : "Grupper",
+    "Circles" : "Cirkler",
+    "Loading" : "Indlæser",
+    "Error" : "Fejl",
+    "Password protect" : "Beskyt med adgangskode",
+    "Back" : "Tilbage",
+    "Close" : "Luk",
+    "Conversation name" : "Samtalenavn",
+    "Reply" : "Besvar",
+    "[Unknown user name]" : "[Ukendt brugernavn] ",
+    "Today" : "I dag",
+    "Yesterday" : "I går",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "File to share" : "Vælg fil til deling",
     "moderator" : "moderator",
+    "guest" : "Gæst",
     "Demote from moderator" : "Degrader fra moderator",
     "Promote to moderator" : "Forfrem til moderator",
     "Remove participant" : "Fjern deltager",
-    "Share link" : "Del link",
+    "No results" : "Ingen resultater",
     "Participants" : "Deltagere",
+    "Rename conversation" : "Omdøb samtale",
+    "Guests" : "Gæster",
+    "Share link" : "Del link",
+    "Password protection" : "Password protection",
+    "Enter a password" : "Enter a password",
+    "Webinar" : "Webinar",
+    "Chat" : "Chat",
+    "Edit" : "Rediger",
+    "Leave call" : "Forlad opkald",
+    "Start call" : "Start opkald",
+    "Limit to groups" : "Begræns til grupper",
+    "Limit app usage to groups." : "Begræns app-brug til grupper.",
+    "Save changes" : "Gem ændringer",
+    "Saving …" : "Gemmer…",
+    "Saved!" : "Gemt!",
     "Name" : "Navn",
+    "General settings" : "Generelle indstillinger",
     "Saved" : "Gemt",
     "Shared secret" : "Delt hemmelighed",
     "STUN servers" : "STUN servere",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
     "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
     "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
-    "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
+    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
+    "Password required" : "Password påkrævet",
     "Password" : "Password",
-    "Fullscreen (f)" : "Vis i fuldskærm (f)",
+    "Cancel" : "Annullér",
+    "Submit" : "Indsend",
+    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
+    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
+    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
+    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
+    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
+    "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
     "TURN server" : "TURN server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
@@ -114,8 +185,8 @@ OC.L10N.register(
     "New group conversation" : "Ny gruppesamtale",
     "{name} (public)" : "{name} (offentlig)",
     "New conversation …" : "Ny samtale …",
-    "Chat" : "Chat",
     "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
+    "Fullscreen (f)" : "Vis i fuldskærm (f)",
     "Copy" : "Kopiér",
     "Copied!" : "Kopieret!",
     "Not supported!" : "Ikke understøttet",
@@ -123,17 +194,9 @@ OC.L10N.register(
     "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
     "Start a conversation" : "Start en samtale",
     "Share" : "Del",
-    "Request password" : "Anmod om adgangskode",
-    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
-    "Password required" : "Password påkrævet",
-    "Cancel" : "Annullér",
-    "Submit" : "Indsend",
-    "Leave call" : "Forlad opkald",
-    "Start call" : "Start opkald",
     "Change password" : "Skift password",
     "Set password" : "Sæt password",
     "Go to file" : "Gå til fil",
-    "Conversation name" : "Samtalenavn",
     "Rename" : "Omdøb",
     "Conversation with {name}" : "Samtale med {name}",
     "Link copied!" : "Link kopieret!",
@@ -141,57 +204,23 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Ingen beskeder endnu, start samtalen!",
     "New message …" : "Ny besked …",
     "Send" : "Send",
-    "Today" : "I dag",
-    "Yesterday" : "I går",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "Der opstod fejl under indsendelse af besked",
-    "File to share" : "Vælg fil til deling",
-    "Edit" : "Rediger",
-    "No other people in this call" : "Ingen andre deltager i dette opkald",
+    "Error while sharing" : "Fejl under deling",
     "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
-    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
-    "Share this link to invite others!" : "Del dette link for at invitere andre!",
     "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
-    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
     "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
-    "This conversation has ended" : "Samtalen er slut",
     "Mute audio" : "Slå lyden fra",
-    "Disable video" : "Deaktiver video",
     "Share screen" : "Del skærm",
-    "Share whole screen" : "Del hele skærmen",
-    "Share a single window" : "Del et vindue",
-    "Show your screen" : "Vis din skærm",
-    "Stop screensharing" : "Stop skærmdeling",
-    "Unmute audio (m)" : "Slå lyden til (m)",
-    "Mute audio (m)" : "Slå lyden fra (m)",
-    "No audio" : "Ingen lyd",
-    "Enable video (v)" : "Slå video til (v)",
-    "Disable video (v)" : "Slå video fra (v)",
     "No Camera" : "Intet kamera",
     "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
-    "Screensharing options" : "Skærmdeling indstillinger",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
-    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
-    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
-    "Enable screensharing" : "Slå skærmdeling til",
     "Add participant …" : "Tilføj deltager…",
     "Favorited" : "Tilføjet til favoritter",
     "Always notify" : "Giv altid besked",
     "Notify on @-mention" : "Giv besked ved @-omtale",
     "Never notify" : "Giv aldrig besked",
-    "Close" : "Luk",
-    "Show screen" : "Vis skærm",
-    "Enable video" : "Slå video til",
-    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
-    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
-    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
-    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
     "{participantName}'s screen" : "{participantName}s skærm",
     "Guest's screen" : "Gæsts skærm",
-    "Your screen" : "Din skærm",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du var inviteret til et <strong>snakke</strong> rum eller fik et <strong>opkald</strong>",
     "_%n other guest_::_%n other guests_" : ["%n anden gæst","%n andre gæster"],
     ", " : ", ",
