@@ -1,91 +1,6 @@
 OC.L10N.register(
     "spreed",
     {
-    "New conversation …" : "Nueva conversación ...",
-    "Participants" : "Participantes",
-    "Chat" : "Chat",
-    "Talk" : "Hablar",
-    "Exit fullscreen (f)" : "Salir de pantalla completa (f)",
-    "Fullscreen (f)" : "Pantalla completa (f)",
-    "Copy" : "Copiar",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
-    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
-    "Password required" : "Contraseña requerida",
-    "Password" : "Contraseña",
-    "Cancel" : "Cancelar",
-    "Submit" : "Enviar",
-    "Leave call" : "Dejar la llamada",
-    "Join call" : "Unirse a la llamada",
-    "Share link" : "Compartir liga",
-    "Change password" : "Cambiar contraseña",
-    "Set password" : "Establecer contraseña",
-    "Name" : "Nombre",
-    "Conversation name" : "Nombre de la conversación",
-    "Rename" : "Renombrar",
-    "Copy link" : "Copiar liga",
-    "Conversation with {name}" : "Conversación con {name}",
-    "Error occurred while setting password" : "Se presentó un error al establecer al contraseña",
-    "Link copied!" : "¡Liga copiada!",
-    "You" : "Tú",
-    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
-    "New message …" : "Mensaje nuevo ...",
-    "Send" : "Enviar",
-    "Guest" : "Invitado",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
-    "Edit" : "Editar",
-    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
-    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
-    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
-    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
-    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
-    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
-    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
-    "This conversation has ended" : "Esta conversación ha terminado",
-    "Disable video" : "Deshabilitar video",
-    "Share screen" : "Compartir la pantalla",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Mute audio (m)" : "Silenciar audio (m)",
-    "Unmute audio (m)" : "Habilitar audio (m)",
-    "No audio" : "Sin audio",
-    "Disable video (v)" : "Deshabilitar video (v)",
-    "Enable video (v)" : "Habilitar video (v)",
-    "No Camera" : "Sin cámara",
-    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
-    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
-    "Screensharing options" : "Opciones de compartir pantalla",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
-    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
-    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
-    "Enable screensharing" : "Habilitar compartir pantalla",
-    "moderator" : "moderador",
-    "Demote from moderator" : "Degradar de moderador",
-    "Promote to moderator" : "Promover a moderador",
-    "Remove participant" : "Eliminar participante",
-    "Add participant …" : "Agregar participante ...",
-    "Delete conversation" : "Borrar conversación",
-    "Your screen" : "Tu pantalla",
-    "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "Close" : "Cerrar",
-    "Show screen" : "Mostrar pantalla",
-    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
-    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
-    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
-    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
-    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "(Duration %s)" : "(Duración %s)",
     "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
     "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
@@ -95,29 +10,149 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
     "_%n other_::_%n others_" : ["%n otro","otros %n"],
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Te invitaron a un cuarto de <strong>conversación</strong> o tuviste una <strong>llamada</strong>",
+    "Talk" : "Hablar",
+    "Guest" : "Invitado",
     "Talk to %s" : "Hablar con %s",
+    "Join call" : "Unirse a la llamada",
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
+    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
+    "This conversation has ended" : "Esta conversación ha terminado",
+    "None" : "Ninguno",
+    "User" : "Usuario",
+    "Everyone" : "Todos",
+    "Disabled" : "Deshabilitado",
+    "Users" : "Usuarios",
     "Validate SSL certificate" : "Validar certificado SSL",
     "TURN server protocols" : "Protocolos del servidor TURN",
     "UDP and TCP" : "UDP y TCP",
     "UDP only" : "UDP únicamente",
     "TCP only" : "TCP únicamente",
+    "Copy link" : "Copiar liga",
+    "No other people in this call" : "No hay más personas en esta llamada",
+    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
+    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
+    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
+    "No audio" : "Sin audio",
+    "Mute audio (m)" : "Silenciar audio (m)",
+    "Unmute audio (m)" : "Habilitar audio (m)",
+    "Disable video (v)" : "Deshabilitar video (v)",
+    "Enable video (v)" : "Habilitar video (v)",
+    "Screensharing options" : "Opciones de compartir pantalla",
+    "Enable screensharing" : "Habilitar compartir pantalla",
+    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
+    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
+    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Your screen" : "Tu pantalla",
+    "Show screen" : "Mostrar pantalla",
+    "Disable video" : "Deshabilitar video",
+    "Enable video" : "Habilitar el video",
+    "Favorite" : "Hacer favorito",
+    "Leave conversation" : "Dejar la conversación",
+    "Delete conversation" : "Borrar conversación",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a tus favoritos",
+    "Conversations" : "Conversaciones",
+    "Contacts" : "Contactos",
+    "Groups" : "Grupos",
+    "Circles" : "Círculos",
+    "Loading" : "Cargando",
+    "Error" : "Error",
+    "Password protect" : "Proteger con contraseña",
+    "Back" : "Atrás",
+    "Close" : "Cerrar",
+    "Conversation name" : "Nombre de la conversación",
+    "Reply" : "Responder",
+    "[Unknown user name]" : "[Nombre de usuario desconocido]",
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "moderator" : "moderador",
+    "Demote from moderator" : "Degradar de moderador",
+    "Promote to moderator" : "Promover a moderador",
+    "Remove participant" : "Eliminar participante",
+    "No results" : "No hay resultados",
+    "Participants" : "Participantes",
+    "Rename conversation" : "Renombrar conversación",
+    "Guests" : "Invitados",
+    "Share link" : "Compartir liga",
+    "Password protection" : "Protección con contraseña",
+    "Enter a password" : "Ingresa una contraseña",
+    "Chat" : "Chat",
+    "Edit" : "Editar",
+    "Leave call" : "Dejar la llamada",
+    "Limit to groups" : "Limitar a grupos",
+    "Save changes" : "Guardar cambios",
+    "Saved!" : "¡Guardado!",
+    "Name" : "Nombre",
+    "General settings" : "Configuraciones generales",
     "Saved" : "Guardado",
     "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
+    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
+    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
+    "Password required" : "Contraseña requerida",
+    "Password" : "Contraseña",
+    "Cancel" : "Cancelar",
+    "Submit" : "Enviar",
+    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
+    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
+    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
+    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
+    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
+    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
+    "Android app" : "Aplicación Android",
+    "iOS app" : "Aplicación iOS",
     "Delete server" : "Borrar servidor",
     "Add new server" : "Agregar un servidor nuevo ",
     "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Borraste todos los servidores STUN. Como casi siempre se necesitan, se agregó un servidor STUN por defecto. ",
     "TURN server shared secret" : "Secreto compartido del servidor TURN",
     "New public conversation" : "Nueva conversación pública",
     "New group conversation" : "Nueva conversación de grupo",
+    "New conversation …" : "Nueva conversación ...",
+    "Exit fullscreen (f)" : "Salir de pantalla completa (f)",
+    "Fullscreen (f)" : "Pantalla completa (f)",
+    "Copy" : "Copiar",
+    "Copied!" : "¡Copiado!",
+    "Not supported!" : "¡No soportado!",
+    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
+    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
+    "Share" : "Compartir",
+    "Change password" : "Cambiar contraseña",
+    "Set password" : "Establecer contraseña",
+    "Rename" : "Renombrar",
+    "Conversation with {name}" : "Conversación con {name}",
+    "Error occurred while setting password" : "Se presentó un error al establecer al contraseña",
+    "Link copied!" : "¡Liga copiada!",
+    "You" : "Tú",
+    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
+    "New message …" : "Mensaje nuevo ...",
+    "Send" : "Enviar",
+    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
+    "Error while sharing" : "Se presentó un error al compartir",
+    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
+    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
+    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
+    "Mute audio" : "Silenciar audio",
+    "Share screen" : "Compartir la pantalla",
+    "No Camera" : "Sin cámara",
+    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
+    "Add participant …" : "Agregar participante ...",
+    "Favorited" : "Marcado como favorito",
+    "{participantName}'s screen" : "Pantalla de {participantName}",
+    "Guest's screen" : "Pantalla del invitado",
+    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Te invitaron a un cuarto de <strong>conversación</strong> o tuviste una <strong>llamada</strong>",
     "_%n other guest_::_%n other guests_" : [" %n otro invitado","%n otros invitados"],
     ", " : ",",
     "A group call has started" : "Una llamada en grupo ha iniciado",
