@@ -1,51 +1,103 @@
 OC.L10N.register(
     "spreed",
     {
-    "Copy" : "Kopjo",
-    "Copied!" : "U kopjua!",
-    "Not supported!" : "Nuk mbështetet!",
-    "Press ⌘-C to copy." : "Shtyni ⌘-C që të kopjoni.",
-    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
-    "Password" : "Fjalëkalim",
-    "Cancel" : "Anulo",
-    "Leave call" : "Lini një thirrje",
-    "Share link" : "Shpërndaj ndërlidhjen",
-    "Rename" : "Riemëroj",
-    "You" : "Ju",
+    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
     "Guest" : "I ftuar",
+    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
+    "None" : "Asnjë",
+    "User" : "Përdorues",
+    "Everyone" : "Kushdo",
+    "Disabled" : "I çaktivizuar",
+    "Users" : "Përdoruesit",
+    "TURN server protocols" : "Protokollet e serverit TURN",
+    "UDP and TCP" : "UDP dhe TCP",
+    "UDP only" : "Vetëm UDP",
+    "TCP only" : "Vetëm TCP",
+    "Copy link" : "Kopjo linkun",
     "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
-    "Waiting for {participantName} to join the call …" : "Duke pritur për {participantName} që ti bashkohet telefonatës ...",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
-    "WebRTC is not supported in your browser :-/" : "WebRTC nuk suportohet nga shfletuesi juaj :-/",
-    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
-    "Waiting for camera and microphone permissions" : "Duke pritur për autorizimin e kameras dhe mikrofonit ",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Ju lutemi, ti jepni akses browser-it tuaj për të përdorur kameran dhe mikrofonin në mënyrë që të përdorni këtë app.",
-    "Disable video" : "Çaktivizo video",
-    "Share screen" : "Ndaje ekranin",
     "Show your screen" : "Shfaq ekranin tënd",
     "Stop screensharing" : "Ndalo ndarjen e ekranit",
-    "Screensharing is not supported by your browser." : "Ndarja e erkaneve nuk është e mbështetur nga shfletuesi juaj ",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
     "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
     "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
     "Your screen" : "Ekrani juaj",
-    "{participantName}'s screen" : "Ekrani i {participantName}",
-    "Guest's screen" : "Ekrani i të ftuarit",
+    "Disable video" : "Çaktivizo video",
+    "Favorite" : "I/E Preferuar",
+    "Leave conversation" : "Largohuni nga biseda",
+    "Delete conversation" : "Fshijeni bisedën",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Shtoje tek të parapëlqyerat",
+    "Conversations" : "Bisedat",
+    "Contacts" : "Kontaktet",
+    "Groups" : "Grupet",
+    "Circles" : "Rrethet",
+    "Loading" : "Duke ngarkuar",
+    "Error" : "Error",
+    "Password protect" : "Mbroje me fjalëkalim",
+    "Back" : "Prapa",
+    "Close" : "Mbylleni",
+    "Conversation name" : "Emri i bisedës",
+    "Reply" : "Përgjigju",
+    "Today" : "Sot",
+    "Yesterday" : "Dje",
+    "guest" : "vizitor",
+    "No results" : "Asnjë rezultat",
+    "Rename conversation" : "Riemërtojeni bisedën",
+    "Guests" : "Të ftuarit",
+    "Share link" : "Shpërndaj ndërlidhjen",
+    "Password protection" : "Password protection",
+    "Enter a password" : "Fusni një fjalëkalim",
+    "Edit" : "Përpuno",
+    "Leave call" : "Lini një thirrje",
+    "Limit to groups" : "Kufizo grupet",
+    "Save changes" : "Ruaj ndryshimet",
+    "Saved!" : "I/E ruajtur!",
+    "Name" : "Emri",
+    "General settings" : "Opsjonet e Pergjithshme",
+    "Saved" : "U ruajt",
+    "Password required" : "Kërkohet fjalëkalimi",
+    "Password" : "Fjalëkalim",
+    "Cancel" : "Anulo",
+    "Submit" : "Dërgo",
     "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
     "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
     "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
+    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
     "Error while accessing microphone & camera" : "gabim ",
-    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
-    "TURN server protocols" : "Protokollet e serverit TURN",
-    "UDP and TCP" : "UDP dhe TCP",
-    "UDP only" : "Vetëm UDP",
-    "TCP only" : "Vetëm TCP",
-    "Saved" : "U ruajt",
+    "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
     "TURN server" : "Serveri TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
+    "Android app" : "Aplikacion Android",
+    "iOS app" : "Aplikacion iOS",
     "TURN server shared secret" : "Serveri TURN ndan sekret",
+    "Test server" : "Shërbyes provash",
+    "New public conversation" : "Bisedë e re publike",
+    "Copy" : "Kopjo",
+    "Copied!" : "U kopjua!",
+    "Not supported!" : "Nuk mbështetet!",
+    "Press ⌘-C to copy." : "Shtyni ⌘-C që të kopjoni.",
+    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
+    "Start a conversation" : "Filloni një bisedë",
+    "Share" : "Shpërndaje",
+    "Change password" : "Ndryshoni fjalëkalimin",
+    "Set password" : "Vendos fjalëkalimin",
+    "Rename" : "Riemëroj",
+    "You" : "Ju",
+    "Send" : "Dërgo",
+    "Error while sharing" : "Gabim gjatë ndarjes",
+    "Waiting for {participantName} to join the call …" : "Duke pritur për {participantName} që ti bashkohet telefonatës ...",
+    "WebRTC is not supported in your browser :-/" : "WebRTC nuk suportohet nga shfletuesi juaj :-/",
+    "Waiting for camera and microphone permissions" : "Duke pritur për autorizimin e kameras dhe mikrofonit ",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Ju lutemi, ti jepni akses browser-it tuaj për të përdorur kameran dhe mikrofonin në mënyrë që të përdorni këtë app.",
+    "Mute audio" : "Mute audio",
+    "Share screen" : "Ndaje ekranin",
+    "Screensharing is not supported by your browser." : "Ndarja e erkaneve nuk është e mbështetur nga shfletuesi juaj ",
+    "Favorited" : "U kalua e parapëlqyer",
+    "{participantName}'s screen" : "Ekrani i {participantName}",
+    "Guest's screen" : "Ekrani i të ftuarit",
     "_%n other guest_::_%n other guests_" : ["%n përdorues të tjerë","%n të tjerë"],
     ", " : ",",
     "%s invited you to a private conversation" : "%s ju ftoi në një bisedë private",
