@@ -20,80 +20,59 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed\AppInfo;
+namespace OCA\Talk\AppInfo;
 
-use OCA\Spreed\Activity\Listener as ActivityListener;
-use OCA\Spreed\Capabilities;
-use OCA\Spreed\Chat\Changelog\Listener as ChangelogListener;
-use OCA\Spreed\Chat\ChatManager;
-use OCA\Spreed\Chat\Command\Listener as CommandListener;
-use OCA\Spreed\Chat\Parser\Listener as ParserListener;
-use OCA\Spreed\Chat\SystemMessage\Listener as SystemMessageListener;
-use OCA\Spreed\Collaboration\Resources\ConversationProvider;
-use OCA\Spreed\Collaboration\Resources\Listener as ResourceListener;
-use OCA\Spreed\Config;
-use OCA\Spreed\Files\Listener as FilesListener;
-use OCA\Spreed\Files\TemplateLoader as FilesTemplateLoader;
-use OCA\Spreed\Listener;
-use OCA\Spreed\Listener\RestrictStartingCalls as RestrictStartingCallsListener;
-use OCA\Spreed\Manager;
-use OCA\Spreed\Middleware\CanUseTalkMiddleware;
-use OCA\Spreed\Middleware\InjectionMiddleware;
-use OCA\Spreed\Notification\Listener as NotificationListener;
-use OCA\Spreed\Notification\Notifier;
-use OCA\Spreed\PublicShareAuth\Listener as PublicShareAuthListener;
-use OCA\Spreed\PublicShareAuth\TemplateLoader as PublicShareAuthTemplateLoader;
-use OCA\Spreed\PublicShare\TemplateLoader as PublicShareTemplateLoader;
-use OCA\Spreed\Room;
-use OCA\Spreed\Settings\Personal;
-use OCA\Spreed\Share\RoomShareProvider;
-use OCA\Spreed\Signaling\Listener as SignalingListener;
-use OCA\Spreed\TalkSession;
+use OCA\Talk\Activity\Listener as ActivityListener;
+use OCA\Talk\Capabilities;
+use OCA\Talk\Chat\Changelog\Listener as ChangelogListener;
+use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Chat\Command\Listener as CommandListener;
+use OCA\Talk\Chat\Parser\Listener as ParserListener;
+use OCA\Talk\Chat\SystemMessage\Listener as SystemMessageListener;
+use OCA\Talk\Collaboration\Resources\ConversationProvider;
+use OCA\Talk\Collaboration\Resources\Listener as ResourceListener;
+use OCA\Talk\Config;
+use OCA\Talk\Events\ChatEvent;
+use OCA\Talk\Events\RoomEvent;
+use OCA\Talk\Files\Listener as FilesListener;
+use OCA\Talk\Files\TemplateLoader as FilesTemplateLoader;
+use OCA\Talk\Flow\Operation;
+use OCA\Talk\Listener;
+use OCA\Talk\Listener\RestrictStartingCalls as RestrictStartingCallsListener;
+use OCA\Talk\Middleware\CanUseTalkMiddleware;
+use OCA\Talk\Middleware\InjectionMiddleware;
+use OCA\Talk\Notification\Listener as NotificationListener;
+use OCA\Talk\Notification\Notifier;
+use OCA\Talk\PublicShare\TemplateLoader as PublicShareTemplateLoader;
+use OCA\Talk\PublicShareAuth\Listener as PublicShareAuthListener;
+use OCA\Talk\PublicShareAuth\TemplateLoader as PublicShareAuthTemplateLoader;
+use OCA\Talk\Room;
+use OCA\Talk\Settings\Personal;
+use OCA\Talk\Share\RoomShareProvider;
+use OCA\Talk\Signaling\Listener as SignalingListener;
 use OCP\AppFramework\App;
-use OCP\AppFramework\Utility\IControllerMethodReflector;
 use OCP\AppFramework\Utility\ITimeFactory;
-use OCP\Collaboration\Resources\IManager as IResourceManager;
+use OCP\Collaboration\Resources\IProviderManager;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IServerContainer;
 use OCP\IUser;
 use OCP\Security\CSP\AddContentSecurityPolicyEvent;
 use OCP\Security\FeaturePolicy\AddFeaturePolicyEvent;
 use OCP\Settings\IManager;
-use Symfony\Component\EventDispatcher\EventDispatcherInterface;
-use Symfony\Component\EventDispatcher\GenericEvent;
+
 
 class Application extends App {
 
+	const APP_ID = 'spreed';
+
 	public function __construct(array $urlParams = []) {
-		parent::__construct('spreed', $urlParams);
-
-		$server = $this->getContainer()->getServer();
-		$this->getContainer()->registerService('CanUseTalkMiddleware', function() use ($server) {
-			/** @var Config $config */
-			$config = $server->query(Config::class);
-			$user = $server->getUserSession()->getUser();
-
-			return new CanUseTalkMiddleware(
-				!$user instanceof IUser ||
-				!$config->isDisabledForUser($user)
-			);
-		});
-
-		$this->getContainer()->registerService('InjectionMiddleware', function() use ($server) {
-			return new InjectionMiddleware(
-				$server->getRequest(),
-				$server->query(IControllerMethodReflector::class),
-				$this->getContainer()->query(TalkSession::class),
-				$this->getContainer()->query(Manager::class),
-				$this->getContainer()->query('userId')
-			);
-		});
+		parent::__construct(self::APP_ID, $urlParams);
 
 		// This needs to be in the constructor,
 		// because otherwise the middleware is registered on a wrong object,
 		// when it is requested by the Router.
-		$this->getContainer()->registerMiddleWare('CanUseTalkMiddleware');
-		$this->getContainer()->registerMiddleWare('InjectionMiddleware');
+		$this->getContainer()->registerMiddleWare(CanUseTalkMiddleware::class);
+		$this->getContainer()->registerMiddleWare(InjectionMiddleware::class);
 	}
 
 	public function register(): void {
@@ -103,7 +82,9 @@ class Application extends App {
 		$this->registerCollaborationResourceProvider($server);
 		$this->getContainer()->registerCapability(Capabilities::class);
 
-		$dispatcher = $server->getEventDispatcher();
+		/** @var IEventDispatcher $dispatcher */
+		$dispatcher = $server->query(IEventDispatcher::class);
+
 		Listener::register($dispatcher);
 		ActivityListener::register($dispatcher);
 		NotificationListener::register($dispatcher);
@@ -120,11 +101,10 @@ class Application extends App {
 		CommandListener::register($dispatcher);
 		ResourceListener::register($dispatcher);
 		ChangelogListener::register($dispatcher);
+		Operation::register($dispatcher);
 
-		/** @var IEventDispatcher $newDispatcher */
-		$newDispatcher = $server->query(IEventDispatcher::class);
-		$newDispatcher->addServiceListener(AddContentSecurityPolicyEvent::class, Listener\CSPListener::class);
-		$newDispatcher->addServiceListener(AddFeaturePolicyEvent::class, Listener\FeaturePolicyListener::class);
+		$dispatcher->addServiceListener(AddContentSecurityPolicyEvent::class, Listener\CSPListener::class);
+		$dispatcher->addServiceListener(AddFeaturePolicyEvent::class, Listener\FeaturePolicyListener::class);
 
 		$this->registerNavigationLink($server);
 		$this->registerRoomActivityHooks($dispatcher);
@@ -138,11 +118,11 @@ class Application extends App {
 	}
 
 	protected function registerCollaborationResourceProvider(IServerContainer $server): void {
-		/** @var IResourceManager $resourceManager */
-		$resourceManager = $server->query(IResourceManager::class);
+		/** @var IProviderManager $resourceManager */
+		$resourceManager = $server->query(IProviderManager::class);
 		$resourceManager->registerResourceProvider(ConversationProvider::class);
 		\OC::$server->getEventDispatcher()->addListener('\OCP\Collaboration\Resources::loadAdditionalScripts', function () {
-			\OCP\Util::addScript('spreed', 'collections');
+			\OCP\Util::addScript(self::APP_ID, 'collections');
 		});
 	}
 
@@ -160,38 +140,34 @@ class Application extends App {
 			$config = $server->query(Config::class);
 			$user = $server->getUserSession()->getUser();
 			return [
-				'id' => 'spreed',
-				'name' => $server->getL10N('spreed')->t('Talk'),
+				'id' => self::APP_ID,
+				'name' => $server->getL10N(self::APP_ID)->t('Talk'),
 				'href' => $server->getURLGenerator()->linkToRouteAbsolute('spreed.Page.index'),
-				'icon' => $server->getURLGenerator()->imagePath('spreed', 'app.svg'),
+				'icon' => $server->getURLGenerator()->imagePath(self::APP_ID, 'app.svg'),
 				'order' => 3,
 				'type' => $user instanceof IUser && !$config->isDisabledForUser($user) ? 'link' : 'hidden',
 			];
 		});
 	}
 
-	protected function registerRoomActivityHooks(EventDispatcherInterface $dispatcher): void {
-		$listener = function(GenericEvent $event) {
-			/** @var Room $room */
-			$room = $event->getSubject();
+	protected function registerRoomActivityHooks(IEventDispatcher $dispatcher): void {
+		$listener = function(ChatEvent $event) {
+			$room = $event->getRoom();
 			/** @var ITimeFactory $timeFactory */
 			$timeFactory = $this->getContainer()->query(ITimeFactory::class);
 			$room->setLastActivity($timeFactory->getDateTime());
 		};
 
-		$dispatcher->addListener(ChatManager::class . '::sendMessage', $listener);
-		$dispatcher->addListener(ChatManager::class . '::sendSystemMessage', $listener);
+		$dispatcher->addListener(ChatManager::EVENT_AFTER_MESSAGE_SEND, $listener);
+		$dispatcher->addListener(ChatManager::EVENT_AFTER_SYSTEM_MESSAGE_SEND, $listener);
 	}
 
-	protected function registerChatHooks(EventDispatcherInterface $dispatcher): void {
-		$listener = function(GenericEvent $event) {
-			/** @var Room $room */
-			$room = $event->getSubject();
-
+	protected function registerChatHooks(IEventDispatcher $dispatcher): void {
+		$listener = function(RoomEvent $event) {
 			/** @var ChatManager $chatManager */
 			$chatManager = $this->getContainer()->query(ChatManager::class);
-			$chatManager->deleteMessages($room);
+			$chatManager->deleteMessages($event->getRoom());
 		};
-		$dispatcher->addListener(Room::class . '::postDeleteRoom', $listener);
+		$dispatcher->addListener(Room::EVENT_AFTER_ROOM_DELETE, $listener);
 	}
 }
