@@ -21,16 +21,16 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed\Controller;
+namespace OCA\Talk\Controller;
 
-use OCA\Spreed\Chat\AutoComplete\SearchPlugin;
-use OCA\Spreed\Chat\AutoComplete\Sorter;
-use OCA\Spreed\Chat\ChatManager;
-use OCA\Spreed\Chat\MessageParser;
-use OCA\Spreed\GuestManager;
-use OCA\Spreed\Model\Message;
-use OCA\Spreed\Room;
-use OCA\Spreed\TalkSession;
+use OCA\Talk\Chat\AutoComplete\SearchPlugin;
+use OCA\Talk\Chat\AutoComplete\Sorter;
+use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Chat\MessageParser;
+use OCA\Talk\GuestManager;
+use OCA\Talk\Model\Message;
+use OCA\Talk\Room;
+use OCA\Talk\TalkSession;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -139,7 +139,7 @@ class ChatController extends AEnvironmentAwareController {
 			$actorId = $sessionId ? sha1($sessionId) : 'failed-to-get-session';
 
 			if ($sessionId && $actorDisplayName) {
-				$this->guestManager->updateName($this->room, $sessionId, $actorDisplayName);
+				$this->guestManager->updateName($this->room, $this->participant, $actorDisplayName);
 			}
 		} else {
 			$actorType = 'users';
@@ -161,7 +161,7 @@ class ChatController extends AEnvironmentAwareController {
 
 			$parentMessage = $this->messageParser->createMessage($this->room, $this->participant, $parent, $this->l);
 			$this->messageParser->parseMessage($parentMessage);
-			if ($parentMessage->getMessageType() === 'system' || $parentMessage->getMessageType() === 'command') {
+			if (!$parentMessage->isReplyable()) {
 				return new DataResponse([], Http::STATUS_BAD_REQUEST);
 			}
 		}
@@ -184,9 +184,9 @@ class ChatController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_CREATED);
 		}
 
-		$data = $this->messageToData($chatMessage);
+		$data = $chatMessage->toArray();
 		if ($parentMessage instanceof Message) {
-			$data['parent'] = $this->messageToData($parentMessage);
+			$data['parent'] = $parentMessage->toArray();
 		}
 		return new DataResponse($data, Http::STATUS_CREATED);
 	}
@@ -289,7 +289,7 @@ class ChatController extends AEnvironmentAwareController {
 				$parentIds[$id] = $comment->getParentId();
 			}
 
-			$messages[] = $this->messageToData($message);
+			$messages[] = $message->toArray();
 			$commentIdToIndex[$id] = $i;
 			$i++;
 		}
@@ -325,14 +325,15 @@ class ChatController extends AEnvironmentAwareController {
 					$this->messageParser->parseMessage($message);
 
 					if ($message->getVisibility()) {
-						$loadedParents[$parentId] = $this->messageToData($message);
+						$loadedParents[$parentId] = $message->toArray();
 						$messages[$commentKey]['parent'] = $loadedParents[$parentId];
-					} else {
-						$loadedParents[$parentId] = [
-							'id' => $parentId,
-							'deleted' => true,
-						];
+						continue;
 					}
+
+					$loadedParents[$parentId] = [
+						'id' => $parentId,
+						'deleted' => true,
+					];
 				} catch (NotFoundException $e) {
 				}
 			}
@@ -365,21 +366,6 @@ class ChatController extends AEnvironmentAwareController {
 		return $response;
 	}
 
-	protected function messageToData(Message $message): array {
-		return [
-			'id' => (int) $message->getComment()->getId(),
-			'token' => $message->getRoom()->getToken(),
-			'actorType' => $message->getActorType(),
-			'actorId' => $message->getActorId(),
-			'actorDisplayName' => $message->getActorDisplayName(),
-			'timestamp' => $message->getComment()->getCreationDateTime()->getTimestamp(),
-			'message' => $message->getMessage(),
-			'messageParameters' => $message->getMessageParameters(),
-			'systemMessage' => $message->getMessageType() === 'system' ? $message->getMessageRaw() : '',
-			'messageType' => $message->getMessageType(),
-		];
-	}
-
 	/**
 	 * @NoAdminRequired
 	 * @RequireParticipant
@@ -426,11 +412,21 @@ class ChatController extends AEnvironmentAwareController {
 
 		$roomDisplayName = $this->room->getDisplayName($this->participant->getUser());
 		if (($search === '' || strpos('all', $search) !== false || stripos($roomDisplayName, $search) !== false) && $this->room->getType() !== Room::ONE_TO_ONE_CALL) {
-			array_unshift($results, [
-				'id' => 'all',
-				'label' => $roomDisplayName,
-				'source' => 'calls',
-			]);
+			if ($search === '' ||
+				stripos($roomDisplayName, $search) === 0 ||
+				strpos('all', $search) === 0) {
+				array_unshift($results, [
+					'id' => 'all',
+					'label' => $roomDisplayName,
+					'source' => 'calls',
+				]);
+			} else {
+				$results[] = [
+					'id' => 'all',
+					'label' => $roomDisplayName,
+					'source' => 'calls',
+				];
+			}
 		}
 
 		return new DataResponse($results);
